# NOTE:
# - release notes: https://github.com/mitchellh/vagrant/blob/master/CHANGELOG.md
Summary:	Provisioning and deployment of virtual instances
Name:		vagrant
Version:	2.1.2
Release:	4
License:	MIT
Group:		Applications/Emulators
Source0:	https://github.com/mitchellh/vagrant/archive/v%{version}/%{name}-%{version}.tar.gz
# Source0-md5:	20b7a4a7b3e1bb4a57c8cac65a547ce7
Source1:	%{name}.sh
Patch1:		rubygems.patch
Patch2:		no-warning.patch
Patch3:		Vagrantfile.patch
Patch4:		version.patch
Patch5:		fix-deps.patch
Patch7:		insert-key.patch
Patch8:		listen.patch
Patch9:		pld-chef-installed.patch
URL:		http://www.vagrantup.com/
BuildRequires:	bash
BuildRequires:	rpm-rubyprov
BuildRequires:	ruby > 1:2.0
%if %{with tests}
BuildRequires:	ruby-contest >= 0.1.2
BuildRequires:	ruby-minitest >= 2.5.1
BuildRequires:	ruby-mocha
BuildRequires:	ruby-rake
BuildRequires:	ruby-rspec >= 2.14.0
%endif
Requires:	bsdtar
Requires:	curl
Requires:	ruby-json
Requires:	ruby-rubygems
Suggests:	VirtualBox
Suggests:	VirtualBox-gui
Suggests:	rdesktop
Suggests:	rsync
BuildArch:	noarch
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%define		_appdir	%{_datadir}/%{name}
%define		bash_compdir	%{_datadir}/bash-completion/completions

%define		vg_home	/home/vagrant
%define		vg_root	/vagrant

%description
Vagrant offers scripted provisioning and deployment of virtual
instances. While VirtualBox is the main target, future versions may
support other hypervizors as well.

The vision of the project is to create a tool to transparently manage
all the complex parts of modern development within a virtual
environment without affecting the everyday workflow of the developer
too much. A long term goal is moving all development into virtualized
environments by making it easier to do so than not to. Additionally,
work is ongoing to have Vagrant run identically on every major
consumer OS platform (Linux, Mac OS X, and Windows).

%package -n bash-completion-%{name}
Summary:	bash-completion for %{name}
Group:		Applications/Shells
Requires:	%{name}
Requires:	bash-completion >= 2.0

%description -n bash-completion-%{name}
bash-completion for %{name}.

%package guest
Summary:	Vagrant guest
Group:		Development/Building
URL:		http://docs-v1.vagrantup.com/v1/docs/base_boxes.html
Requires(postun):	/usr/sbin/userdel
Requires(pre):	/bin/id
Requires(pre):	/usr/bin/getgid
Requires(pre):	/usr/sbin/groupadd
Requires(pre):	/usr/sbin/useradd
Requires:	/etc/pld-release
Requires:	openssh-server
Requires:	sudo >= 1.7.4p3-2
Requires:	which
Suggests:	kernel(vboxsf)
Provides:	group(vagrant)
Provides:	user(vagrant)

%description guest
This is the package to be installed in Vagrant guest.

WARNING: This package installs insecure keypair to vagant user. Do not
install this package in a box that is accessible others but you.

These keys are the "insecure" public/private keypair we offer to base
box creators for use in their base boxes so that vagrant installations
can automatically SSH into the boxes.

See: <https://github.com/mitchellh/vagrant/tree/master/keys/>.

%package doc
Summary:	Documentation for %{name}
Group:		Documentation
Requires:	%{name} = %{version}-%{release}

%description doc
Ruby documentation for %{gem_name}

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1

VERSION=$(cat version.txt)
sed -i -e "s/__VERSION__/$VERSION/" lib/vagrant/version.rb

# cleanup backups after patching
find '(' -name '*~' -o -name '*.orig' ')' -print0 | xargs -0 -r -l512 rm -f

%build
# make gemspec self-contained
ruby -r rubygems -e 'spec = eval(File.read("%{name}.gemspec"))
	File.open("%{name}-%{version}.gemspec", "w") do |file|
	file.puts spec.to_ruby_for_cache
end'

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT{%{ruby_gemdir}/gems/%{name}-%{version},%{ruby_specdir},%{_bindir}}
cp -a lib bin keys plugins templates $RPM_BUILD_ROOT%{ruby_gemdir}/gems/%{name}-%{version}
cp -p %{name}-%{version}.gemspec $RPM_BUILD_ROOT%{ruby_specdir}
install -p %{SOURCE1} $RPM_BUILD_ROOT%{_bindir}/%{name}

install -d $RPM_BUILD_ROOT%{bash_compdir}
cp -p contrib/bash/completion.sh $RPM_BUILD_ROOT%{bash_compdir}/%{name}

# guest
install -d $RPM_BUILD_ROOT/etc/sudoers.d
echo 'vagrant ALL=(ALL) NOPASSWD: ALL' > $RPM_BUILD_ROOT/etc/sudoers.d/%{name}

install -d $RPM_BUILD_ROOT{%{vg_root},%{vg_home}/.ssh}
cp -p /etc/skel/.bash*  $RPM_BUILD_ROOT%{vg_home}

# Since Vagrant only supports key-based authentication for SSH, we must
# set up the vagrant user to use key-based authentication. We can get the
# public key used by the Vagrant gem directly from its Github repository.
cp -p keys/vagrant.pub $RPM_BUILD_ROOT%{vg_home}/.ssh/authorized_keys

%clean
rm -rf $RPM_BUILD_ROOT

%pre guest
%groupadd -g 291 vagrant
%useradd -u 291 -g vagrant -G wheel -c "Vagrant user" -s /bin/bash -d %{vg_home} vagrant

%postun guest
if [ "$1" = "0" ]; then
	%userremove vagrant
	%groupremove vagrant
fi

%files
%defattr(644,root,root,755)
%attr(755,root,root) %{_bindir}/vagrant
#%{ruby_vendorlibdir}/vagrant.rb
#%{ruby_vendorlibdir}/vagrant
#%{_appdir}

%dir %{ruby_gemdir}/gems/%{name}-%{version}
%dir %{ruby_gemdir}/gems/%{name}-%{version}/bin
%attr(755,root,root) %{ruby_gemdir}/gems/%{name}-%{version}/bin/*
%{ruby_gemdir}/gems/%{name}-%{version}/keys
%{ruby_gemdir}/gems/%{name}-%{version}/lib
%{ruby_gemdir}/gems/%{name}-%{version}/plugins
%{ruby_gemdir}/gems/%{name}-%{version}/templates

%{ruby_specdir}/%{name}-%{version}.gemspec

%files -n bash-completion-%{name}
%defattr(644,root,root,755)
%{bash_compdir}/%{name}

%files guest
%defattr(644,root,root,755)
%attr(440,root,root) %config(noreplace) %verify(not md5 mtime size) /etc/sudoers.d/%{name}
%dir %attr(750,vagrant,vagrant) %{vg_home}
%dir %attr(700,vagrant,vagrant) %{vg_home}/.ssh
%attr(600,vagrant,vagrant) %config(noreplace) %verify(not md5 mtime size) %{vg_home}/.ssh/authorized_keys
%dir %attr(640,vagrant,vagrant) %{vg_home}/.bash*
%dir %attr(700,root,root) %{vg_root}

%if 0
%files doc
%defattr(644,root,root,755)
%doc %{gem_docdir}
%endif
%changelog
* Sun Oct 27 2019 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/vagrant.git;a=log;h=master

* Fri Feb 22 2019 Elan Ruusamäe <glen@pld-linux.org> 6c09bd0
- lib/pre-rubygems.rb is gone

* Sun Jul 15 2018 Jan Rękorajski <baggins@pld-linux.org> bd9c408
- merge existing patches and fix various nonsenical deps
- rel 3

* Sun Jul 15 2018 Jan Rękorajski <baggins@pld-linux.org> 2ca22df
- relax net-ssh dependency (5.0.0 has just a bunch of new features)
- rel 2

* Mon Jul 09 2018 Jan Rękorajski <baggins@pld-linux.org> 58e2297
- up to 2.1.2

* Fri Jul 29 2016 Elan Ruusamäe <glen@delfi.ee> 051d9c6
- vagrant-guest: make kernel integration optional

* Sat Mar 19 2016 Elan Ruusamäe <glen@delfi.ee> 66b4371
- drop manual deps

* Sat Mar 19 2016 Elan Ruusamäe <glen@delfi.ee> c34ee10
- bump net-ssh dep

* Fri Mar 18 2016 Jan Rękorajski <baggins@pld-linux.org> 07cec44
- release 4 (by relup.sh)

* Thu Mar 17 2016 Jan Rękorajski <baggins@pld-linux.org> 09747e0
- release 3 (by relup.sh)

* Tue Sep 01 2015 Elan Ruusamäe <glen@delfi.ee> 865f5ef
- upstream rejects this

* Tue Sep 01 2015 Elan Ruusamäe <glen@delfi.ee> 89ea5f1
- VirtualBox is optional (can use other providers)

* Fri Aug 21 2015 Elan Ruusamäe <glen@delfi.ee> e775e16
- fix networking detection for pld

* Fri Aug 21 2015 Elan Ruusamäe <glen@delfi.ee> cf7a6c1
- add note how to disable insert key per user

* Wed Aug 19 2015 Elan Ruusamäe <glen@delfi.ee> 85167f5
- instal chef provision no longer relevant as vagrant can do that itself

* Wed Aug 19 2015 Elan Ruusamäe <glen@delfi.ee> 27c6553
- chef: add pld cap to install chef

* Wed Aug 19 2015 Elan Ruusamäe <glen@delfi.ee> 3353e2a
- use chef-client as test, not knife

* Wed Aug 19 2015 Elan Ruusamäe <glen@delfi.ee> 168102b
- fix chef-installed patch

* Wed Aug 19 2015 Elan Ruusamäe <glen@delfi.ee> d291d61
- drop obsolete source_root.patch

* Wed Aug 19 2015 Elan Ruusamäe <glen@delfi.ee> 28281fb
- override chef install location in pld

* Wed Aug 19 2015 Elan Ruusamäe <glen@delfi.ee> 8d17cac
- up to 1.7.4 (July 17, 2015)

